<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\Models\User;
use App\Models\Companyinfo;
use App\Models\CoreActivity;
use App\Models\Activity;
use App\Models\Category;
use App\Models\MembershipPlan;
use App\Models\Countries;
use App\Models\State;
use App\Models\City;
use App\Models\Designation;
use App\Models\Transaction;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;
use Stripe\Stripe;
use Stripe\Customer;
use Stripe\Charge;
use Mail;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'fname' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\Models\User
     */
     public function index()
    {       

        $countries = Countries::get();
        $designations = Designation::where('status',1)->get(); 
        return view('auth.register',
            [
            'countries'=>$countries,
            'designations'=>$designations,
        ]);

        //return view('auth.register');
    }


     public function createStepOne(Request $request)
    {

        $validator =Validator::make($request->all(),
        [
                'fname'              => 'required',
                'lname'              => 'required',
                'email'              => 'required',
                'mobile'             => 'required|min:10|max:10',
                //'user_company'  => 'required',
                //'user_designation'        => 'required',
                'country'            => 'required',
                'state'              => 'required',
                'city'               => 'required',
                //'postcode'           => 'required', 
                'password'           => 'required|min:6',
                'confirm_password' => 'required_with:password|same:password|min:6',
                'address'             => 'required',
                'created_at' => date('Y-m-d h:i:s'),
                'updated_at' =>date('Y-m-d h:i:s'),
        ]);

        if ($validator->fails()) {
            return $validator->validate();
        }else{
            $email_exists = User::where('email', $request->email)->first();
            if ($email_exists) {
                return response()->json(['error'=>1,'details' => 'Email already exists.']);
            }
            $id = $request->id;
            $obj = User::firstOrNew(['id' =>$id]);
            $obj->fname = $request->fname;
            $obj->lname = $request->lname;
            $obj->email = $request->email;
            $obj->mobile = $request->mobile;                
            $obj->country = $request->country;
            $obj->state = $request->state;
            $obj->city = $request->city;               
            $obj->password = Hash::make($request->password);
            $obj->address = $request->address;  
            $obj->zipcode = $request->zipcode; 
            //$obj->user_designation = $request->user_designation; 
            //$obj->user_company = $request->user_company; 
            $obj->is_seller = $request->is_seller;
            $obj->status = 0;
            $obj->created_at = date('Y-m-d h:i:s');
            $obj->updated_at = date('Y-m-d h:i:s');
            $obj->save();
            $obj->id;

            if ($request->is_seller) {
                $insert_users =  Companyinfo::insert([
                    //'designation' => $request->designation,
                    //'organization_name' => $request->organization_name,
                    'user_id' => $obj->id,
                    'created_at' => $obj->created_at,
                    'updated_at' =>$obj->updated_at,
                ]);
            } else {
                $to_name = $obj->fname;
                $to_email = $obj->email;             

                $this->user_registration_mail($obj);

            }
       }
      
       return response()->json(['success'=>1,'f_id' => $obj->id,'user_email' => $obj->email, 'user_name' => $obj->fname.' '.$obj->lname]);
    }

     public function createSteptwo(Request $request)
    {  
         $insert_users =  Companyinfo::where('company_info.user_id',$request->next_id)->update([
                    'user_id' => $request->next_id,
                    'brief_company' => $request->brief_company,
                    'category_sell' => $request->category_sell,
                    'category_buy' => $request->category_buy,
                    'core_activity' => $request->core_activity,
                    'activity' => $request->activity,
                    'designation' => $request->designation,
                    'organization_name' => $request->organization_name,
                    'contact_person' => $request->contact_person,
                    'company_phone' => $request->company_phone,
                    'company_email' => $request->company_email,
                    'company_website' => $request->company_website,
                    'company_location' => $request->company_location,
          ]);
      
       return response()->json(['success'=>1]);
    }

    public function step_first(Request $request)
    {   
        $countries = Countries::get();
        $designations = Designation::where('status',1)->get(); 
        return view('auth.steps.step_one',
            [
            'countries'=>$countries,
            'designations'=>$designations,
        ]);
    }

    public function step_second(Request $request)
    {   
       $coreActivities = CoreActivity::where('status',1)->get();
       $categories = Category::where('status',1)->get();
       $designations = Designation::where('status',1)->get(); 
        return view('auth.steps.step_two',
            [
            'coreActivities'=>$coreActivities,
            'categories'=>$categories,
            'designations'=>$designations,
        ]);
    }
    public function step_three(Request $request)
    {   

        $plans = MembershipPlan::where('status', 1)->get();
        return view('auth.steps.step_three', 
            [
                'plans'=>$plans,
              
            ]);
        //echo "<pre>";print_r($plans);die;
        // return view('auth.steps.step_three');

    }
    public function plan_update(Request $request)
    {   
        $membership_plan_id = $request->plan_select;
        $plan_select = MembershipPlan::where('status', 1)->where('id', $membership_plan_id)->first();
        //echo '<pre>'; print_r($plan_select->price); die;

         $insert_users =  User::where('users.id',$request->next_id)->update([
                    'id' => $request->next_id,
                    'membership_plan_id' => $membership_plan_id,
                    'plan_price' => $plan_select->price,
          ]);
      
       return response()->json(['success'=>1]);

    }
    
public function state_data($country_id)
    {
         $all_states = State::where('country_id',$country_id)->get()->toArray(); 
          $states = '';
         foreach ($all_states as $key => $state) {
              $states .= '<option value="'.$state['id'].'">'.$state['name'].'</option>'; 
         }
         return $states;
    }
    public function state(Request $request)
    {
         $country_id = $request->id;
         $all_states =  $this->state_data($country_id); 
         return response()->json(['success'=>1,'all_states'=>$all_states]);
    }

     public function city_data($state_id)
    {

         $all_cities = City::where('state_id',$state_id)->get()->toArray(); 

          $cities = '';
         foreach ($all_cities as $key => $city) {
             
              $cities .= '<option value="'.$city['id'].'">'.$city['name'].'</option>'; 
         }

         return $cities;
    }
    public function city(Request $request)
    {
         $state_id = $request->id;

         $all_city =  $this->city_data($state_id); 
         return response()->json(['success'=>1,'all_city'=>$all_city]);
    }
    protected function create(array $data)
    {
        return User::create([
            'fname' => $data['name'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
        ]);
    }

    public function get(Request $request)
    {   
        $cat='';
        $coreactivities = Activity::where('coreactivity',$request->id)->where('status',1)->get();
        foreach($coreactivities as $coreactivity){
            $selected='';
            if($request->sub_cat == $coreactivity->id){$selected='selected';}
            $cat .='<option value="'.$coreactivity->id.'" '.$selected.'>'.$coreactivity->name.'</option>';
        }
        return $cat;
    }

    public function plan_details(Request $request)
    {   
        $membership_plan_id = $request->plan_select;
        $plan_data = MembershipPlan::where('id', $membership_plan_id)->first();
        $user_data =  User::where('id',$request->next_id)->first();

        if ($plan_data->price == 0) {
            $this->user_registration_mail($user_data);
        }
      
       return response()->json(['success'=>1, 'user_data' => $user_data, 'plan_data' => $plan_data]);
    
    }

    public function stripe_charge(Request $request)
    {
        /*dd($request->all());
        die;*/

        $user_id = $_POST['user_id'];
        $plan_id = $_POST['plan_id'];
        $total_payment = $_POST['total_payment'];

        $user_data = User::where('id', $user_id)->first();
        $plan_data = MembershipPlan::where('id', $plan_id)->first();

        try {

            Stripe::setApiKey(env('STRIPE_SECRET_KEY'));

            $customer = Customer::create(array(
                'email' => $request->stripeEmail,
                'source' => $request->stripeToken
            ));

            $charge = Charge::create(array(
                'customer' => $customer->id,
                'amount' => $total_payment * 100,
                'currency' => 'usd'
            ));

            $charge_id = $charge->id;

            $transaction = Transaction::insert([
                'user_id' => $user_id,
                'plan_id' => $plan_id,
                'total_amount' => $total_payment,
                'customer_details' => $customer,
                'charge_details' => $charge,
                'charge_id' => $charge_id,
                'status' => 1,
                'created_at' => date('Y-m-d h:i:s'),
                'updated_at' => date('Y-m-d h:i:s'),
            ]);

            $this->user_registration_mail($user_data);

            return view('auth.payment_success',
            [
                'user_data' => $user_data,
                'plan_data' => $plan_data,
                'charge_id' => $charge_id, 
                'msg' => 'Payment success',
                'title' => 'Payment success'
            ]);

        } catch (\Exception $ex) {

            $this->user_registration_mail($user_data);

            return view('auth.payment_error',
            [
                'user_data' => $user_data,
                'plan_data' => $plan_data,
                'charge_id' => '', 
                'msg' => $ex->getMessage(),
                'title' => 'Payment failed'
            ]);

            //return $ex->getMessage();
        }
    }

    public function user_registration_mail($user_data){ 

        // User email
        $to_name = $user_data->fname;
        $to_email = $user_data->email;   
        $email_token = md5($to_email).rand(10,9999);      

        $city_data = City::where('id', $user_data->city)->first();
        $state_data = State::where('id', $user_data->state)->first();
        $country_data = Countries::where('id', $user_data->country)->first();
        if ($city_data) {
            $user_data->city_name = $city_data->name;
        } else {
            $user_data->city_name = '';
        }
        if ($state_data) {
            $user_data->state_name = $state_data->name;
        } else {
            $user_data->state_name = '';
        }
        if ($country_data) {
            $user_data->country_name = $country_data->name;
        } else {
            $user_data->country_name = '';
        }   
        
        $user = User::firstOrNew(['id' => $user_data->id]);
        $user->email_token = $email_token;               
        $user->save();

        $link = url('/')."/email-verification?key=".urlencode($to_email)."&token=".$email_token;
        $verification_link = "<a href='".$link."'>Click and Verify Email</a>";
        $data = array('user_data' => $user_data, 'verification_link' => $verification_link);
        $message = "User email verification";
        $subject = env('MAIL_FROM_NAME')." - User email verification";            
        Mail::send('emails.users.verification', $data, function($message) use ($to_name, $to_email,$subject) {
            $message->from(env('MAIL_FROM_ADDRESS'),env('MAIL_FROM_NAME'));
            $message->to($to_email, $to_name)
            ->subject($subject);     
        }); 

        // Admin email
        $admin_name = env('ADMIN_NAME');
        $admin_email = env('ADMIN_EMAIL');                
        $admin_data = array('user_data' => $user_data, 'name' => $admin_name);
        $admin_message = "New user registration";
        $admin_subject = env('MAIL_FROM_NAME')." - New user registration";     

        Mail::send('emails.admin.user_registration', $admin_data, function($message) use ($admin_name, $admin_email, $admin_subject) {
            $message->from(env('MAIL_FROM_ADDRESS'),env('MAIL_FROM_NAME'));
            $message->to($admin_email, $admin_name)
            ->subject($admin_subject);  
        });

    }

    public function user_mail_verification(Request $request)
    {
        $email = isset($request->key) ? urldecode($request->key) : '';
        $token = isset($request->token) ? $request->token : '';

        if ($email && $token) {
            $user_data = User::where('email', $email)->first();

            if ($user_data) {

                $email_token = $user_data->email_token;

                if ($email_token == '') {
                    return view('emails.users.verify',
                    [
                        'email' => $email,
                        'token' => $token,
                        'title' => 'Email already verified',
                        'content' => 'Your email account already verified. No further action required from your side.',
                        'status' => 'error',
                        'user_name' => $user_data->fname
                    ]); 
                }

                if ($email_token == $token) {
                    $user = User::firstOrNew(['email' => $email]);
                    $user->email_token = '';
                    $user->save();
                    return view('emails.users.verify',
                    [
                        'email' => $email,
                        'token' => $token,
                        'title' => 'Email verification successful',
                        'content' => 'Your email account has been verified successfully. You can login to your account after admin approval.',
                        'status' => 'success',
                        'user_name' => $user_data->fname
                    ]); 
                } else {
                    return view('emails.users.verify',
                    [
                        'email' => $email,
                        'token' => $token,
                        'title' => 'Email verification failed',
                        'content' => 'Your email account could not be verified. Please check the email verification link send to your email again or contact to website support for more details.',
                        'status' => 'error',
                        'user_name' => $user_data->fname
                    ]); 
                }           
            } else {
                return view('emails.users.verify',
                [
                    'email' => $email,
                    'token' => $token,
                    'title' => 'Invalid user account',
                    'content' => 'We could not found any account registered with your email. Please contact to website admin for further help.',
                    'status' => 'error',
                    'user_name' => 'Visitor'
                ]);
            }
            
        } else {
            return view('emails.users.verify',
            [
                'email' => $email,
                'token' => $token,
                'title' => 'Access denied',
                'content' => 'You are not allowed to access this page.',
                'status' => 'error',
                'user_name' => 'Visitor'
            ]);
        }
    }
}
