<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Countries;
use App\Models\State;
use App\Models\City;
use App\Models\Admin;
use App\Models\Companyinfo;
use App\Models\ProductEnquiry;
use App\Models\Role;
use App\Models\Product;
use App\Models\Category;
use App\Models\SubCategory;
use App\Models\Color;
use Validator;
use Auth;
use Illuminate\Support\Facades\Hash;

class AdminUsersController extends Controller
{
    protected $page;
    protected $module;
    protected $single_heading;
    protected $modal;
    protected $route;
    

    public function __construct(){
        $this->page = new \stdClass;
        $this->modal = 'App\Models\Admin';
        $this->route = new \stdClass;
        $this->module = 'users';
        $this->single_heading = 'Admin';
        $this->route->list = route('admin.users.list');
        $this->route->add = route('admin.users.add');
        $this->route->store = route('admin.users.store');
        $this->route->edit = route("admin.users.edit", ":id");
        $this->route->destroy = route("admin.users.destroy", ":id");
        $this->route->status = route('admin.users.status');
    }
    
    public function index()
    {

        $this->page->title = $this->module.' List';
        return view('admin.'.$this->module.'.index', [
            'page' => $this->page,
            'route'=>$this->route,
            'module'=>$this->module,
            'single_heading'=>$this->single_heading
        ]);
    }
    
    
    public function list(Request $request)
    {
        ## Read value
        $draw = $_POST['draw'];
        $row = $_POST['start'];
        $rowperpage = $_POST['length']; // Rows display per page
        $columnIndex = $_POST['order'][0]['column']; // Column index
        $columnName = $_POST['columns'][$columnIndex]['data']; // Column name
        $columnSortOrder = $_POST['order'][0]['dir']; // asc or desc
        $searchValue = $_POST['search']['value']; // Search value


        $totalRecords =$this->modal::all()->count();
        //$totalRecords = $this->modal::where('fname', 'LIKE','%'.$searchValue.'%')->orWhere('email', 'LIKE','%'.$searchValue.'%')->get()->count();

       $totalRecordwithFilter =$totalRecords;

       $qry = Admin::orderBy($columnName, $columnSortOrder)->offset($row)->take($rowperpage);
        
        //$qry = Admin::orderBy($columnName, $columnSortOrder)->offset($row)->take($rowperpage)->where('name', 'LIKE','%'.$searchValue.'%')->orWhere('email', 'LIKE','%'.$searchValue.'%');
       
      
       $result=$qry->get();

        $data = array();
        $i=1;
        foreach ($result as $row) {
             $status_url = $this->route->status;
             // echo $status_url;die;
            if($row->status == 1){   
                $status = '<div class="form-check form-switch">  <input class="form-check-input" type="checkbox"  checked="" onchange=status_change("'.$status_url.'",this,'.$row->id.');>   </div>';   
             }else{  
                 $status = '<div class="form-check form-switch"> <input class="form-check-input" type="checkbox"  onchange=status_change("'.$status_url.'",this,'.$row->id.');> </div>';   
            }

            $is_seller ='';    
            if($row->is_seller == 1){   
                $is_seller = '<span class="badge bg-dark">Yes</span>';   
             }

            $edit_url = $this->route->edit;
            $destroy_url = $this->route->destroy;
            $action ='<div class="d-flex  order-actions">';
            $action .='<a href="#!" onclick=edit_row("'.$edit_url.'",'.$row->id.',"modal-xl");><i class="bx bxs-edit"></i></a>';
            $action .='&nbsp;&nbsp;<a href="#!" class="" onclick=delete_row("'.$destroy_url.'",'.$row->id.')><i class="bx bxs-trash""></i></a>';
             $action .='</div>';
            $data[] = array(
                    "sno"=>'<input class="form-check-input me-3 filed_check" name="check[]"  type="checkbox"  value="'.$row->id.'"> <a href="user-profile">'.$row->id.'</a>',
                    "name"=>$row->name.'<br>'.$row->email.'<br>'.$row->mobile,
                    "address"=>$row->address,
                    "status"=>$status,
                    "created_at"=>date('Y-m-d h:i A',strtotime($row->created_at)),
                    "action"=>$action,
                );
        
        $i++;
        }


        ## Response
        $response = array(
          "draw" => intval($draw),
          "iTotalRecords" => $totalRecords,
          "iTotalDisplayRecords" => $totalRecordwithFilter,
          "aaData" => $data
        );

        echo json_encode($response);
    }
    
    public function create()
    {  
        $all_countries = Countries::all(); 
        $roles = Role::all(); 
        return view('admin.'.$this->module.'.add', [
            'route'=>$this->route,
            'module'=>$this->module,
            'roles'=>$roles,
            'single_heading'=>$this->single_heading,
            'all_countries'=>$all_countries,
        ]);
    }


    public function store(Request $request)
    { 
        $id = $request->id;
        if($id){
            return $this->update_data($request);
        }else{
            $validator =Validator::make($request->all(),
            [
                
                'name'              => 'required',
                'email'              => 'required',
                'mobile'             => 'required|min:10|max:10',
                'password'           => 'required',
                'status'             => 'required',
                'country'            => 'required',
                'about'              => 'required',
                'postcode'              => 'required',
                'address'              => 'required',
                'is_seller'              => 'required',
                'state'              => 'required',

            ]);
        
            if ($validator->fails()) {
                return $validator->validate();
            }else{ 
                  $insert_users =  Admin::insert([
                    'name' => $request->name,
                    'email' => $request->email,
                    'password' => Hash::make($request->password),
                    'status' => $request->status,
                    'remember_token' => $request->remember_token,
                    'state' => $request->state,
                    'country' => $request->country,
                    'is_seller' => $request->is_seller,
                    'role' => $request->role,
                    'address' => $request->address,
                    'postcode' => $request->postcode,
                    'about' => $request->about,
                    'mobile' => $request->mobile,
                    'email_verified_at' => date('Y-m-d h:i:s'),
                    'created_at' => date('Y-m-d h:i:s'),
                    'updated_at' =>date('Y-m-d h:i:s'),
                ]);

               
                // echo  '<pre>'; print_r($insert_users);die;
               
                return response()->json(['success'=>1,'message'=>$this->single_heading.' created successfully.']);
            }
        }
    }


  public function edit($id)
    {   
        $all_countries = Countries::all(); 
             
        $info = Admin::where('id',$id)->first(); 
       
        $all_state = State::where('country_id', $info->country)->get(); 
        $all_cities = City::where('state_id', $info->state)->get(); 
        $roles = Role::all(); 
        return view('admin.'.$this->module.'.edit', [
            'info' => $info,
            'route'=>$this->route,
            'module'=>$this->module,
            'roles'=>$roles,
            'all_countries'=>$all_countries,
            'all_state'=> $all_state,
            'all_cities'=> $all_cities,
            'single_heading'=>$this->single_heading
        ]);
    }

    public function update_data(Request $request)
    { 
        
        $validator =Validator::make($request->all(),
        [
            
           'name'              => 'required',
            'mobile'             => 'required|min:10|max:10',
            'status'             => 'required',
            'country'            => 'required',
            'about'              => 'required',
            'postcode'              => 'required',
            'address'              => 'required',
            'is_seller'              => 'required',
            'state'              => 'required',
        ]);
       
        if ($validator->fails()) {
            return $validator->validate();
        }else{  
                $update_users =  Admin::where('admins.id',$request->id)->update([
                    'name' => $request->name,
                    'email' => $request->email,
                    'password' => Hash::make($request->password),
                    'status' => $request->status,
                    'remember_token' => $request->remember_token,
                    'state' => $request->state,
                    'country' => $request->country,
                    'is_seller' => $request->is_seller,
                    'address' => $request->address,
                    'role' => $request->role,
                    'postcode' => $request->postcode,
                    'about' => $request->about,
                    'mobile' => $request->mobile,
                    'email_verified_at' => date('Y-m-d h:i:s'),
                    'updated_at' => date('Y-m-d h:i:s'),
                ]);
                // echo '<pre>'; print_r($update_users);die;

            return response()->json(['success'=>1,'message'=>$this->single_heading.' updated successfully.']);
        }
    }


    public function destroy($id)
    {
        $info = Admin::find($id);
        $user_info = Admin::where('id',$id)->first(); 
        $info->delete();
        $user_info->delete();
        return response()->json(['success'=>1,'message'=>$this->single_heading.' delete successfully.']);
    }

    public function status(Request $request)
    {
         $status = $this->modal::find($request->id);        
         $status->status = $request->status; 
         $status->save();
         return response()->json(['success'=>1,'message'=>$this->single_heading.' status update successfully.']);
    }  
    public function state_data($country_id)
    {
         $all_states = State::where('country_id',$country_id)->get()->toArray(); 
          $states = '';
         foreach ($all_states as $key => $state) {
              $states .= '<option value="'.$state['id'].'">'.$state['name'].'</option>'; 
         }
         return $states;
    }
    public function state(Request $request)
    {
         $country_id = $request->id;
         $all_states =  $this->state_data($country_id); 
         return response()->json(['success'=>1,'message'=>$this->single_heading.' successfully.','all_states'=>$all_states]);
    }

    public function city_data($state_id)
    {

         $all_cities = City::where('state_id',$state_id)->get()->toArray(); 

          $cities = '';
         foreach ($all_cities as $key => $city) {
             
              $cities .= '<option value="'.$city['id'].'">'.$city['name'].'</option>'; 
         }

         return $cities;
    }
    public function city(Request $request)
    {
         $state_id = $request->id;

         $all_city =  $this->city_data($state_id); 
         return response()->json(['success'=>1,'message'=>$this->single_heading.' successfully.','all_city'=>$all_city]);
    }

    
    public function destroy_multiple(Request $request)
    {
        $ids = $request->ids;
        $this->modal::destroy($ids);
        $user_info = Admin::destroy($ids); 
        // echo $user_info;die;     
        return response()->json(['success'=>1,'message'=>$this->single_heading.' deleted successfully.']);
    }
    public function user_profile($id)
    {
        $user = User::select('users.*','company_info.postcode','company_info.company_location','company_info.company_website','company_info.company_email','company_info.contact_person','company_info.company_phone','company_info.core_activity','company_info.activity','company_info.nature_business','company_info.category_buy','company_info.category_sell','company_info.callin_pin','company_info.brief_company','company_info.membership_plan','company_info.designation','company_info.category_sell','company_info.organization_name','membership_plans.name as membership_plan','designations.name as designation')->leftJoin('company_info','users.id','=','company_info.user_id','company_info.core_activity','company_info.activity')->leftJoin('membership_plans','company_info.membership_plan','=','membership_plans.id')->leftJoin('designations','company_info.designation','=','designations.id')->where('users.id',$id)->first();

        /*select('users.*','company_info.membership_plan','company_info.designation','company_info.category_sell','company_info.organization_name','membership_plans.name as membership_plan','designations.name as designation')->where('id',$id)->leftjoin('company_info', 'company_info.user_id', '=', 'users.id')->leftJoin('designations','company_info.designation','=','designations.id')->first();*/

         return view('admin.'.$this->module.'.user_profile', [
            
            'route'=>$this->route,
            'module'=>$this->module,
            'single_heading'=>$this->single_heading,
            'user' => $user
        ]);
    }

    public function seller_product_enquiry_list(Request $request)
    { 
        $vendor_id = $request->id;
        $draw = $request->draw;
        $row = $request->start;
        $rowperpage = $request->length; // Rows display per page
        $columnIndex = $_POST['order'][0]['column']; // Column index
        $columnName = $_POST['columns'][$columnIndex]['data']; // Column name
        $columnSortOrder = $_POST['order'][0]['dir']; // asc or desc
        $searchValue = $_POST['search']['value']; // Search value

        $product_enquiries = ProductEnquiry::where('vendor_id', $vendor_id)->orderBy('id','DESC')->get();
        $totalRecords = count($product_enquiries);

        $totalRecordwithFilter = $totalRecords;

        $qry = ProductEnquiry::where('vendor_id', $vendor_id)->orderBy('id','DESC')->offset($row)->take($rowperpage);
       
        $result=$qry->get();
        $data = array();
        $i=1;
        //echo '<pre>';
        foreach ($product_enquiries as $key => $enquiry) {
            $user = User::where('id', $enquiry->user_id)->first();
            if ($user) {
                $buyer_name = $user->fname.' '.$user->lname;
            } else {
                $buyer_name = '';
            }
            $vendor = User::where('id', $enquiry->vendor_id)->first();
            if ($vendor) {
                $seller_name = $vendor->fname.' '.$vendor->lname;
            } else {
                $seller_name = '';
            }
            $product = Product::where('id', $enquiry->product_id)->first();
            if ($product) {
                $product_name = $product->title;
            } else {
                $product_name = '';
            }
            $product_category = Category::where('id', $enquiry->category)->first();
            if ($product_category) {
                $category_name = $product_category->name;
            } else {
                $category_name = '';
            }
            $product_sub_category = SubCategory::where('id', $enquiry->sub_category)->first();
            if ($product_sub_category) {
                $sub_category_name = $product_sub_category->name;
            } else {
                $sub_category_name = '';
            }
            $product_sub_category = SubCategory::where('id', $enquiry->sub_category)->first();
            if ($product_sub_category) {
                $sub_category_name = $product_sub_category->name;
            } else {
                $sub_category_name = '';
            }
            //print_r($product_category);
            $data[] = array(
                "sno"=>$i,
               /* "enquiry_number"=> '<a href="'.url('admin-view-enquiry/'.$row->enquiry_number.'').'">'.$row->enquiry_number.'</a>',*/
               "enquiry_number"=> '<a href="/admin/seller_enquiry_details/'.$enquiry->enquiry_number.'">'.$enquiry->enquiry_number.'</a>',
                "name"=> $buyer_name,
                "email"=>$user->email,
                "product_id"=>$product_name,
                "product_category"=>$category_name,
                "product_sub_category"=>$sub_category_name,
                "quantity"=>$enquiry->quantity,
                "vendor_id"=>$seller_name,
                "status"=>$enquiry->status,
                "created_at"=>date('Y-m-d h:i A',strtotime($enquiry->created_at)),
            );
            $i++;
        }
        //die;

        $response = array(
            "draw" => intval($draw) ,
            "iTotalRecords" => $totalRecords,
            "iTotalDisplayRecords" => $totalRecordwithFilter,
            "aaData" => $data
        );
        echo json_encode($response);
        die;

    }

    public function seller_product_enquiry_details($code)
    {

        $enquiry = ProductEnquiry::where('enquiry_number',$code)->first();

      $product = Product::where('id',$enquiry->product_id)->first();
      if ($product) {
        $product_title = $product->title;
        $product_cat = $product->category;
        $product_sub_cat = $product->sub_category;
      } else {
        $product_title = '';
        $product_cat = '';
        $product_sub_cat = '';
      }
      if ($product_cat) {
        $product_category = Category::where('id',$product_cat)->first();
      } else {
        $product_category = '';
      }    
      if ($product_sub_cat) {
        $product_sub_category = SubCategory::where('id',$product_sub_cat)->first();
      } else {
        $product_sub_category = '';
      }  

      return view('admin.enquiries.seller_enquiry_details',
      [
       
        'enquiry' => $enquiry,
        'product' => $product,
        'product_category' => $product_category,
        'product_sub_category' => $product_sub_category,
      ]
      );
    }

    public function buyer_product_enquiry_list(Request $request)
    { 
        $user_id = $request->id;
        $draw = $request->draw;
        $row = $request->start;
        $rowperpage = $request->length; // Rows display per page
        $columnIndex = $_POST['order'][0]['column']; // Column index
        $columnName = $_POST['columns'][$columnIndex]['data']; // Column name
        $columnSortOrder = $_POST['order'][0]['dir']; // asc or desc
        $searchValue = $_POST['search']['value']; // Search value

        $product_enquiries = ProductEnquiry::where('user_id', $user_id)->orderBy('id','DESC')->get();
        $totalRecords = count($product_enquiries);

        $totalRecordwithFilter = $totalRecords;

        $qry = ProductEnquiry::where('user_id', $user_id)->orderBy('id','DESC')->offset($row)->take($rowperpage);
       
        $result=$qry->get();
        $data = array();
        $i=1;
        //echo '<pre>';
        foreach ($product_enquiries as $key => $enquiry) {
            $user = User::where('id', $enquiry->user_id)->first();
            if ($user) {
                $buyer_name = $user->fname.' '.$user->lname;
            } else {
                $buyer_name = '';
            }
            $vendor = User::where('id', $enquiry->vendor_id)->first();
            if ($vendor) {
                $seller_name = $vendor->fname.' '.$vendor->lname;
            } else {
                $seller_name = '';
            }
            $product = Product::where('id', $enquiry->product_id)->first();
            if ($product) {
                $product_name = $product->title;
            } else {
                $product_name = '';
            }
            $product_category = Category::where('id', $enquiry->category)->first();
            if ($product_category) {
                $category_name = $product_category->name;
            } else {
                $category_name = '';
            }
            $product_sub_category = SubCategory::where('id', $enquiry->sub_category)->first();
            if ($product_sub_category) {
                $sub_category_name = $product_sub_category->name;
            } else {
                $sub_category_name = '';
            }
            $product_sub_category = SubCategory::where('id', $enquiry->sub_category)->first();
            if ($product_sub_category) {
                $sub_category_name = $product_sub_category->name;
            } else {
                $sub_category_name = '';
            }
            //print_r($product_category);
            $data[] = array(
                "sno"=>$i,
               /* "enquiry_number"=> '<a href="'.url('admin-view-enquiry/'.$row->enquiry_number.'').'">'.$row->enquiry_number.'</a>',*/
               "enquiry_number"=> '<a href="/admin/buyer_enquiry_details/'.$enquiry->enquiry_number.'">'.$enquiry->enquiry_number.'</a>',
                "name"=> $buyer_name,
                "email"=>$user->email,
                "product_id"=>$product_name,
                "product_category"=>$category_name,
                "product_sub_category"=>$sub_category_name,
                "quantity"=>$enquiry->quantity,
                "vendor_id"=>$seller_name,
                "status"=>$enquiry->status,
                "created_at"=>date('Y-m-d h:i A',strtotime($enquiry->created_at)),
            );
            $i++;
        }
        //die;

        $response = array(
            "draw" => intval($draw) ,
            "iTotalRecords" => $totalRecords,
            "iTotalDisplayRecords" => $totalRecordwithFilter,
            "aaData" => $data
        );
        echo json_encode($response);
        die;

    }

    public function buyer_product_enquiry_details($code)
    {
        $user_id = 179;
        $enquiry = ProductEnquiry::where('enquiry_number',$code)->first();

      $product = Product::where('id',$enquiry->product_id)->first();
      if ($product) {
        $product_title = $product->title;
        $product_cat = $product->category;
        $product_sub_cat = $product->sub_category;
      } else {
        $product_title = '';
        $product_cat = '';
        $product_sub_cat = '';
      }
      if ($product_cat) {
        $product_category = Category::where('id',$product_cat)->first();
      } else {
        $product_category = '';
      }    
      if ($product_sub_cat) {
        $product_sub_category = SubCategory::where('id',$product_sub_cat)->first();
      } else {
        $product_sub_category = '';
      }  

      return view('admin.enquiries.buyer_enquiry_details',
      [
       
        'enquiry' => $enquiry,
        'product' => $product,
        'product_category' => $product_category,
        'product_sub_category' => $product_sub_category,
      ]
      );
    }

    public function seller_product_list(Request $request)
    { 
        $vendor_id = $request->id;
        $draw = $request->draw;
        $row = $request->start;
        $rowperpage = $request->length; // Rows display per page
        $columnIndex = $_POST['order'][0]['column']; // Column index
        $columnName = $_POST['columns'][$columnIndex]['data']; // Column name
        $columnSortOrder = $_POST['order'][0]['dir']; // asc or desc
        $searchValue = $_POST['search']['value']; // Search value

        $products = Product::where('user_id', $vendor_id)->orderBy('id','DESC')->get();
        $totalRecords = count($products);

        $totalRecordwithFilter = $totalRecords;

        /*$qry = Product::where('vendor_id', $vendor_id)->orderBy('id','DESC')->offset($row)->take($rowperpage);
       
        $result=$qry->get();*/
        $data = array();
        $i=1;
        //echo '<pre>';
        foreach ($products as $key => $product) {
            $category_name = '';
            $sub_category_name = '';
            $product_name = $product->title;
            $product_category = Category::where('id', $product->category)->first();
            if ($product_category) {
                $category_name = $product_category->name;
            }
            $product_sub_category = SubCategory::where('id', $product->sub_category)->first();
            if ($product_sub_category) {
                $sub_category_name = $product_sub_category->name;
            }
            if ($product->color) {
                $colors = explode(',', $product->color);
                if (is_array($colors) && !empty($colors)) {
                    $color_finish = '';
                    foreach ($colors as $key => $color) {
                        $color_data = Color::where('id', $color)->first();
                        if ($color_data) {
                            $color_finish .= $color_data->title.', ';
                        } else {
                            $color_finish .= '';
                        }
                    }
                } else {
                    $color_data = Color::where('id', $product->color)->first();
                    if ($color_data) {
                        $color_finish = $color_data->title;
                    } else {
                        $color_finish = '';
                    }
                }                
            }
            $color_finish = rtrim($color_finish, ', ');
            if ($product->status == 1) {
                $status = 'Public';
            } else {
                $status = 'Private';
            }
            $data[] = array(
                "sno"=>$i,
               /* "enquiry_number"=> '<a href="'.url('admin-view-enquiry/'.$row->enquiry_number.'').'">'.$row->enquiry_number.'</a>',*/
               "product_id"=> '<a href="/admin/products/'.$product->id.'/edit'.$product->id.'">'.$product->id.'</a>',
                "product_title"=> $product_name,
                "product_code"=>$product->code,
                "product_category"=>$category_name,
                "product_sub_category"=>$sub_category_name,
                "color_finish"=>$color_finish,
                "sizes"=>$product->size,
                "status"=>$status,
                "created_at"=>date('Y-m-d h:i A',strtotime($product->created_at)),
            );
            $i++;
        }
        //die;

        $response = array(
            "draw" => intval($draw) ,
            "iTotalRecords" => $totalRecords,
            "iTotalDisplayRecords" => $totalRecordwithFilter,
            "aaData" => $data
        );
        echo json_encode($response);
        die;

    }
}
