<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\SiteSettings;
use App\Models\UploadImage;
use App\Models\Admin;
use Validator;
use Illuminate\Support\Facades\Hash;

class SiteSettingsController extends Controller
{
	protected $page;
    protected $module;
    protected $single_heading;
    protected $modal;
    protected $route;
    

    public function __construct(){
        $this->page = new \stdClass;
        $this->route = new \stdClass;
        $this->route->store = route('sitesettings.store');
        $this->route->upload = route("sitesettings.upload");
        $this->route->favicon_upload = route("sitesettings.favicon.upload");
    }
	
    public function index()
    {
        //echo $this->route->add;die;
		$this->page->title = 'Site Settings';
        return view('admin.site_settings.index', [
            'page' => $this->page
        ]);
    }
	
    public function get_setting_page(Request $request)
    {
        $info=array();
        $settings = SiteSettings::all();
        foreach($settings  as $setting){
          
            $info[$setting->meta_key]=$setting->meta_value;
           
        }
       $logo_file_id = SiteSettings::where('meta_key','logo_file_id')->first(); 
       $logo_url = UploadImage::where('id',$logo_file_id->meta_value)->first(); 

       $favicon_file_id = SiteSettings::where('meta_key','favicon_file_id')->first(); 
       $favicon_url = UploadImage::where('id',$favicon_file_id->meta_value)->first(); 
       
		return view('admin.site_settings.'.$request->file,[
            'info'=>$info,
            'logo_url'=>$logo_url,
            'favicon_url'=>$favicon_url,
            'route'=>$this->route
        ]);
    }


    public function store(Request $request)
    { 
      $page = $request->page;
      $request->request->remove('_token');
      $request->request->remove('page');
     
      foreach($request->all() as $k=>$v){
       
          SiteSettings::where('meta_key',$k)->update(['meta_value'=>$v]);
      }
      
       return response()->json(['success'=>1,'message'=>$page.' Updated successfully']);
	}


    public function admin_password_update(Request $request)
    {
        $validator =Validator::make($request->all(),
		[
            'old_password'          => 'required',
            'new_password'          => 'required|min:6|max:10',
            'confirm_password'          => 'required|same:new_password',
        ]);
		if ($validator->fails()) {
            return $validator->validate();
        }else{
			 $admin = Admin::find(auth()->guard('admin')->user()->id);
			if (Hash::check($request->old_password, $admin->password)) { 
			   
				$admin->password = Hash::make($request->new_password);
				$admin->save();
				return response()->json(['success'=>1,'message'=>'Password updated successfully.']);
			} else {
				return response()->json(['success'=>2,'message'=>'Old Password does not match.']);
			}
		}
    }

        public function upload(Request $request)
    {
        $this->validate($request, [
            'logo' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);
        $type = $request->type;
        $path = $type.'_path';
        $name = $type.'_name';
        $file_path = $request->$path;
        $file_name = $request->$name;

        $ext_arr= array('jpg','png','jpeg'); 
        
        //$file_path = 'upload/siteSettings/';
        //if ($request->hasFile('logo_img')) {
        if(!empty($request->file($file_name))){ 
            $file = $request->file($file_name);
            $ext = $file->getClientOriginalExtension();
            //$image = $request->file('logo_img');
            if(in_array($ext,$ext_arr)){
                $destinationPath = public_path().'/'.$file_path;
                $file_name = time()."_".$file->getClientOriginalName();
                $file->move($destinationPath,$file_name);

                $file_data = UploadImage::create([
                    'file'          => $file_path.$file_name, 
                ]);
                return response()->json(['status'=>1,'file_id'=>$file_data->id,'file_path'=>asset($file_data->file)]);
            } else {
                return response()->json(['status'=>0,'msg'=>'File type not allowed']);
            }
            //$name = time().'.'.$image->getClientOriginalExtension();
            // $destinationPath = public_path('/images');
            /*$destinationPath = public_path().'/'.$file_path;;
            $image->move($destinationPath, $name);*/

            

            
        }

        
    }
	     public function favicon_upload(Request $request)
    {

      $this->validate($request, [
        'favicon_img' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
    ]);
     $file_path = 'upload/siteSettings/';
    if ($request->hasFile('favicon_img')) {
        $image = $request->file('favicon_img');
        $name = time().'.'.$image->getClientOriginalExtension();
        // $destinationPath = public_path('/images');
        $destinationPath = public_path().'/'.$file_path;;
        $image->move($destinationPath, $name);

        $file_data = UploadImage::create([
                'file'          => $file_path.$name, 
                ]);

        return response()->json(['status'=>1,'file_id'=>$file_data->id,'file_path'=>asset($file_data->file)]);
    }
        
    }
    
}
